@@ -352,4 +352,56 @@ class fillVars(object, cl_base.glob_attr):
         fullHostName = "%s.%s"%(hostName,domain)
         if fullHostName in replSambaServers:
             return "on"
-        return "off"
\ No newline at end of file
+        return "off"
+
+    def get_sr_samba_net_allow_pass(self):
+        """Текст в smb.conf - доступные сети"""
+        netAllow = self.Get("sr_samba_net_allow")
+        if netAllow:
+            netAllow = netAllow.split(",")
+            foundLoc = False
+            for net in netAllow:
+                if net[:4] == '127.':
+                    foundLoc = True
+                    break
+            netAllow = " ".join(netAllow)
+            if not foundLoc:
+                netAllow += " 127."
+            return netAllow
+        osNetAllow = self.Get("os_net_allow")
+        if osNetAllow:
+            return "%s 127." %osNetAllow
+        return "127."
+
+    def get_sr_mail_net_allow_pass(self):
+        """Текст в main.cf - доступные сети"""
+        netAllow = self.Get("sr_mail_net_allow")
+        if netAllow:
+            netAllow = netAllow.split(",")
+            foundLoc = False
+            for net in netAllow:
+                if net[:4] == '127.':
+                    foundLoc = True
+                    break
+            netAllow = ", ".join(netAllow)
+            if not foundLoc:
+                netAllow += ", 127.0.0.0/8"
+            return netAllow
+        osNetAllow = self.Get("os_net_allow")
+        if osNetAllow:
+            return "%s, 127.0.0.0/8" %osNetAllow
+        return "127.0.0.0/8"
+
+    def get_sr_samba_net_allow(self):
+        """Доступные сети для сервиса Samba"""
+        netAllow = self.Get("os_net_allow")
+        if netAllow:
+            return netAllow
+        return ""
+
+    def get_sr_mail_net_allow(self):
+        """Доступные сети для сервиса Mail"""
+        netAllow = self.Get("os_net_allow")
+        if netAllow:
+            return netAllow
+        return ""
\ No newline at end of file
