@@ -311,12 +311,6 @@ class Data:
     #V soft_ldap_admin_mailpw_hash
     ld_mail_hash = {}
 
-    #почтовый релей
-    # Пример заполнения:
-    #    value:', 212.113.122.130'
-    #soft_ldap_mail_relay
-    sr_mail_relay = {}
-
     # Директория хранения писем
     #V soft_ldap_mail_path
     sr_mail_path = {'value':'/var/calculate/server-data/mail'}
@@ -392,7 +386,7 @@ class Data:
     # Calculate плюс версия калкулэйта для записи в заголовок файла
     # объединяемого с профилем
     #setup_name
-    cl_ver = {'value':'Calculate-server 2.0.7'}
+    cl_ver = {'value':'Calculate-server 2.0.8'}
 
     #DN LDAP ветки, в котором будут находится служебные ветки
     ld_ldap_dn = {}
@@ -432,4 +426,13 @@ class Data:
     # id серверов репликации
     ld_repl_ids = {}
     # Включена или нет репликация для сервиса Samba
-    ld_repl_samba_set = {}
\ No newline at end of file
+    ld_repl_samba_set = {}
+
+    # Доступные сети для сервиса Samba
+    sr_samba_net_allow = {}
+    # Текст в smb.conf - доступные сети
+    sr_samba_net_allow_pass = {}
+    # Доступные сети для сервиса Mail
+    sr_mail_net_allow = {}
+    # Текст в main.cf - доступные сети
+    sr_mail_net_allow_pass = {}
\ No newline at end of file
